@@ -1,4 +1,4 @@
-'''
+r'''
 # aws-fargate-dynamodb module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -136,6 +136,9 @@ Out of the box implementation of the Construct without any override will set the
 
 © Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -193,7 +196,7 @@ class FargateToDynamoDB(
         :param ecr_image_version: The version of the image to use from the repository. Default: - 'latest'
         :param ecr_repository_arn: The arn of an ECR Repository containing the image to use to generate the containers. format: arn:aws:ecr:[region]:[account number]:repository/[Repository Name]
         :param existing_container_definition_object: -
-        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
+        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
         :param existing_table_interface: Optional user provided props to override the default props for DynamoDB Table. Default: - None
         :param existing_vpc: An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing Fargate service, this value must be the VPC where the service is running. An DynamoDB Interface endpoint will be added to this VPC. Default: - none
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
@@ -305,7 +308,7 @@ class FargateToDynamoDBProps:
         :param ecr_image_version: The version of the image to use from the repository. Default: - 'latest'
         :param ecr_repository_arn: The arn of an ECR Repository containing the image to use to generate the containers. format: arn:aws:ecr:[region]:[account number]:repository/[Repository Name]
         :param existing_container_definition_object: -
-        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
+        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
         :param existing_table_interface: Optional user provided props to override the default props for DynamoDB Table. Default: - None
         :param existing_vpc: An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing Fargate service, this value must be the VPC where the service is running. An DynamoDB Interface endpoint will be added to this VPC. Default: - none
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
@@ -440,7 +443,7 @@ class FargateToDynamoDBProps:
 
         If
         this is specified, then no props defining a new service can be provided, including:
-        existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps,
+        existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps,
         ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value
         is provided, then existingContainerDefinitionObject must be provided as well.
 
